Page 31 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 31

Home

    For we wrestle not against flesh and blood, but
    against principalities, against powers, against the rulers
    of the darkness of this world, against spiritual

    14 ne oc ee

    The organization that has had the greatest impact
    upon events occurring since the later part of the 18th
    century is a secret society founded in Bavaria in 1776. Its
    founder, Adam Weishaupt, a professor of canon law at
    the University of Ingolstadt, labeled it the Illuminati

    Order.

    The pretended purpose of the Order was to bring
    universal happiness to the human race by promoting
    world brotherhood and equality. The true purpose of the
    Order, hidden behind layers of secrecy, was to rule the

    world. To achieve this goal the Order set out to destroy
    all religion, overthrow all governments, and abolish all
    existing social order, such as the family and ownership
    of private property. This plan has been followed by the
    Communists since 1848.

    26

    Chapter 5

    The Iluminati

    wickedness in high places.

    Ephesians 6:12